@@ -35,7 +35,7 @@ class LidarAnnotationTask(Task):
         """
         if not scene.scale_file_attachments:  # s3 upload
             assert (
-                scene.public_url
+                scene.base_url
             ), "No public URL on scene, please upload or save the scene first"
 
         # Get client using environ api key
@@ -47,7 +47,7 @@ class LidarAnnotationTask(Task):
 
         # Load scene params
         if not scene.scale_file_attachments:  # s3 upload
-            scene_dict = scene.to_dict(scene.public_url)
+            scene_dict = scene.to_dict(scene.base_url)
             param_dict["attachments"] = scene_dict["frames"]
         else:  # scale file upload
             param_dict["attachments"] = scene.scale_file_attachments
@@ -144,7 +144,7 @@ class LidarTopDownTask(Task):
 
         """
         assert (
-            scene.public_url
+            scene.base_url
         ), "No public URL on scene, please upload or save the scene first"
 
         # Get client using environ api key
@@ -156,7 +156,7 @@ class LidarTopDownTask(Task):
 
         # Load scene params
         if not scene.scale_file_attachments:  # s3 upload
-            scene_dict = scene.to_dict(scene.public_url)
+            scene_dict = scene.to_dict(scene.base_url)
             param_dict["attachments"] = scene_dict["frames"]
         else:  # scale file upload
             param_dict["attachments"] = scene.scale_file_attachments
@@ -223,7 +223,7 @@ class LidarSegmentationTask(Task):
 
         """
         assert (
-            scene.public_url
+            scene.base_url
         ), "No public URL on scene, please upload or save the scene first"
 
         # Get client using environ api key
@@ -235,7 +235,7 @@ class LidarSegmentationTask(Task):
 
         # Load scene params
         if not scene.scale_file_attachments:  # s3 upload
-            scene_dict = scene.to_dict(scene.public_url)
+            scene_dict = scene.to_dict(scene.base_url)
             param_dict["attachments"] = scene_dict["frames"]
         else:  # scale file upload
             param_dict["attachments"] = scene.scale_file_attachments
